import { FASTElement } from '@microsoft/fast-element';
/**
 * Defines a property changed handler that calls a render() method on the target as an internal observation enhancement.
 *
 * @remarks
 * This is useful if you have a lot of properties that all invalidate the internal state.
 * See {@link https://www.fast.design/docs/fast-element/observables-and-state#internal-observation} for more information.
 *
 * @param target - The target to define the property change handler on.
 * @param name - The property name.
 *
 * @example
 * ```ts
 *  @attr({ mode: 'boolean', attribute: 'line-numbers' })
 *  @renderOnChange
 *  lineNumbers: boolean = true;
 *
 *  @attr
 *  @renderOnChange
 *  indent: number | 'tab' = 2;
 *
 *  render() {
 *    if (!this.$fastController.isConnected) {
 *      return;
 *    }
 *    // Do something...
 *  }
 * ```
 *
 * @public
 */
export declare function renderOnChange(target: FASTElement & {
    render(): void;
}, name: string): void;
//# sourceMappingURL=renderOnChange.d.ts.map