import type { DTOMapper } from './types';
/**
 * @internal
 */
type LowercaseOperation = 'insert' | 'modify' | 'delete';
/**
 * @internal
 */
type UppercaseOperation = Uppercase<LowercaseOperation>;
/**
 * The data for a server row DTO.
 * @public
 */
export type ServerRowDTO = {
    DETAILS: {
        OPERATION: UppercaseOperation;
        ROW_REF: string;
    };
};
/**
 * The data for a server row entity.
 * @public
 */
export type ServerRowEntity = {
    serverRowMetadata: {
        operation: LowercaseOperation;
        rowRef: string;
    };
};
/**
 * A mapper for converting between server row DTOs and entities.
 * Provides methods to get/set a ServerRow DTO entity mapping.
 * @public
 */
export interface ServerRowDTOMapper extends DTOMapper<ServerRowDTO, ServerRowEntity> {
}
/**
 * The default `ServerRowDTOMapper`.
 * @public
 */
export declare class DefaultServerRowDTOMapper implements ServerRowDTOMapper {
    /**
     * Converts a server row DTO to an entity.
     * @param dto - The DTO to convert.
     * @returns The resulting entity.
     * @public
     */
    fromDTO: (dto: ServerRowDTO) => ServerRowEntity;
    /**
     * Converts a server row entity to a DTO.
     * @param entity - The entity to convert.
     * @returns The resulting DTO.
     * @public
     */
    toDTO: (entity: ServerRowEntity) => ServerRowDTO;
}
/**
 * A DI token used to obtain a `ServerRowDTOMapper` instance.
 * @public
 */
export declare const ServerRowDTOMapper: import("@microsoft/fast-foundation").InterfaceSymbol<ServerRowDTOMapper>;
export {};
//# sourceMappingURL=serverRow.d.ts.map