/**
 * Creates an observer that facilitates the subscription and publication of events.
 * @public
 */
export type Listener<EventType> = (ev: EventType) => void;
/**
 * Subscribes a listener function to receive events of a specific type.
 * @public
 */
export type Subscribe<EventType> = (listener: Listener<EventType>) => () => void;
/**
 * Publishes an event of a specific type to all subscribed listeners.
 * @public
 */
export type Publish<EventType> = (event: EventType) => void;
/**
 * Represents an event observer that manages the subscription and publication of events.
 * @public
 */
export interface Observer<EventType> {
    subscribe: Subscribe<EventType>;
    publish: Publish<EventType>;
}
/**
 * Creates a new event observer instance.
 * @public
 */
export declare const createObserver: <EventType>() => Observer<EventType>;
/**
 * Setup an `IntersectionObserver` which will activate a callback function when an element becomes visible on screen
 * @param element - HTMLElement to observe
 * @param callback - any function called when the visibility changes
 * @public
 */
export declare const respondToVisibility: (element: HTMLElement, callback: (arg0: boolean) => any) => void;
//# sourceMappingURL=observer.d.ts.map