import { JSONSerializerConfig } from './json.types';
/**
 * A Default Number Parser for deserializing objects.
 * @public
 */
export declare function customNumberParser(value: any): number | bigint;
/**
 * An interface representing a JSON serializer.
 * @public
 */
export interface JSONSerializer {
    /**
     * Serializes an object to a JSON string.
     * @param object - The object to serialize.
     * @returns The serialized JSON string.
     */
    serialize(object: any): string;
    /**
     * Deserializes a response object from a HTTP request to a JavaScript object.
     * @param response - The HTTP response object.
     * @returns A promise that resolves to the deserialized JavaScript object.
     */
    deserialize<T = any>(response: Response): Promise<T>;
    /**
     * Deserializes a message event object to a JavaScript object.
     * @param event - The message event object.
     * @returns The deserialized JavaScript object.
     */
    deserialize<T = any>(event: MessageEvent): T;
    /**
     * Deserializes a JSON string to a JavaScript object.
     * @param text - The JSON string to deserialize.
     * @returns The deserialized JavaScript object.
     */
    deserialize<T = any>(text: string): T;
}
/**
 * A Default JSONSerializer Config for serializing and deserializing functions.
 * @public
 */
export declare const defaultJSONSerializerConfig: JSONSerializerConfig;
export default class DefaultJSONSerializer implements JSONSerializer {
    private config;
    constructor(config?: JSONSerializerConfig);
    /**
     * @inheritDoc JSONSerializer.serialize
     */
    serialize: (object: any) => string;
    /**
     * @inheritDoc JSONSerializer.deserialize
     */
    deserialize<T>(input: any): any;
}
/**
 * A DI token for the JSON serializer.
 * @public
 */
export declare const JSONSerializer: import("@microsoft/fast-foundation").InterfaceSymbol<JSONSerializer>;
//# sourceMappingURL=json.d.ts.map