/**
 * Loads font faces by inserting a style element with the specified font face rules into the document.
 * @param fontFaceRules - The CSS rules for the font faces.
 * @param styleElementId - The ID of the style element to insert into the document.
 * @public
 */
export declare const loadFontFaces: (fontFaceRules: string, styleElementId: string) => void;
/**
 * An enum of possible font styles.
 * @public
 */
export declare enum FontStyle {
    Italic = "italic",
    Normal = "normal"
}
/**
 * An enum of possible font weights.
 * @public
 */
export declare enum FontWeight {
    Thin = 100,
    Light = 300,
    Regular = 400,
    Medium = 500,
    Bold = 700,
    Black = 900
}
/**
 * Generates a CSS mixin for the specified font family, style, and weight.
 * @param family - The font family.
 * @param style - Optional. The font style. Defaults to FontStyle.Normal.
 * @param weight - Optional. The font weight. Defaults to FontWeight.Regular.
 * @returns The generated CSS mixin.
 * @public
 */
export declare const getFontMixin: (family: string, style?: FontStyle, weight?: FontWeight) => string;
/**
 * An object containing type ramp values.
 * @public
 */
export declare const TypeRampValues: {
    readonly minusOne: -1;
    readonly minusTwo: -2;
    readonly plusOne: 1;
    readonly plusTwo: 2;
    readonly plusThree: 3;
    readonly plusFour: 4;
    readonly plusFive: 5;
    readonly plusSix: 6;
};
//# sourceMappingURL=typography.d.ts.map