/**
 * Directive that allows supplying an "else" template to the traditional {@link https://www.fast.design/docs/api/fast-element.when/#when-function} directive
 *
 * @param binding - The condition to test for rendering.
 * @param trueTemplateOrTemplateBinding - The template or a binding that gets the template to render when the condition is true.
 * @param falseTemplateOrTemplateBinding - The template or a binding that gets the template to render when the condition is false.
 * @public
 */
export function whenElse(binding, trueTemplateOrTemplateBinding, falseTemplateOrTemplateBinding) {
    const getTemplate = (template) => typeof template === 'function' ? template : () => template;
    const trueTemplate = getTemplate(trueTemplateOrTemplateBinding);
    const falseTemplate = getTemplate(falseTemplateOrTemplateBinding);
    return (source, context) => binding(source, context) ? trueTemplate(source, context) : falseTemplate(source, context);
}
