import { DI } from '@microsoft/fast-foundation';
/**
 * The default `ServerRowDTOMapper`.
 * @public
 */
export class DefaultServerRowDTOMapper {
    constructor() {
        /**
         * Converts a server row DTO to an entity.
         * @param dto - The DTO to convert.
         * @returns The resulting entity.
         * @public
         */
        this.fromDTO = (dto) => {
            var _a, _b, _c;
            return ({
                serverRowMetadata: {
                    operation: (_b = (_a = dto === null || dto === void 0 ? void 0 : dto.DETAILS) === null || _a === void 0 ? void 0 : _a.OPERATION) === null || _b === void 0 ? void 0 : _b.toLowerCase(),
                    rowRef: (_c = dto === null || dto === void 0 ? void 0 : dto.DETAILS) === null || _c === void 0 ? void 0 : _c.ROW_REF,
                },
            });
        };
        /**
         * Converts a server row entity to a DTO.
         * @param entity - The entity to convert.
         * @returns The resulting DTO.
         * @public
         */
        this.toDTO = (entity) => {
            var _a, _b, _c;
            return ({
                DETAILS: {
                    OPERATION: (_b = (_a = entity === null || entity === void 0 ? void 0 : entity.serverRowMetadata) === null || _a === void 0 ? void 0 : _a.operation) === null || _b === void 0 ? void 0 : _b.toUpperCase(),
                    ROW_REF: (_c = entity === null || entity === void 0 ? void 0 : entity.serverRowMetadata) === null || _c === void 0 ? void 0 : _c.rowRef,
                },
            });
        };
    }
}
/**
 * A DI token used to obtain a `ServerRowDTOMapper` instance.
 * @public
 */
export const ServerRowDTOMapper = DI.createInterface((x) => x.singleton(DefaultServerRowDTOMapper));
