import { __classPrivateFieldGet, __classPrivateFieldSet } from "tslib";
/** @internal **/
const CLEANUP_TIMEOUT_MS = 10000;
/**
 * @beta
 * Mixin class to expose `shouldRunConnect` and `shouldRunDisconnect`
 *
 * @remarks These can be used to control what lifecycle functionality is ran when the elements
 * are part of a custom layout. The class itself handles all events
 * @privateRemarks
 * #_ syntax is used for a javascript private method/variable
 * we can't use private/protected from typescript in an anonymous class like this
 */
export const LifecycleMixin = (Base) => { var _instances, __container, __latestTokenCode, __hasFirstLoaded, __cleanupTimeout, __shouldForceLifecycle, __blockLifecycleDueToTokenChange, __tryFindContainingLayout, _a; return _a = class extends Base {
        constructor(...args) {
            super(args);
            _instances.add(this);
            /** @internal **/
            __container.set(this, { _key: 'dom' });
            /**
             * If the token changes we suggest blocking the lifecycle methods
             * @internal
             **/
            __latestTokenCode.set(this, '');
            /**
             * Track first loaded to allow us to always run the connect lifecycle on the first load
             * @internal
             **/
            __hasFirstLoaded.set(this, false);
            /**
             * When you request to delete an item from the layout it will be removed from the DOM,
             * but the lifecycle might be blocked due to the same mechanism that we block the other
             * items.
             * This would block cleanup of the item, so we need to force a disconnection after a timeout
             * if this item hasn't reconnected within `CLEANUP_TIMEOUT_MS`.
             * @internal
             **/
            __cleanupTimeout.set(this, void 0);
            /**
             * Used to force lifecycle to run even if the token has changed, such as in instances where
             * we are forcing a disconnection due to this item being remove from the layout.
             * @internal
             **/
            __shouldForceLifecycle.set(this, false);
        }
        /**
         * @privateRemarks
         * Rather than using the basic implementation of cloning we run a copy constructor (deepClone)
         * and then manually clone the children too so they can intercept with an overriden cloneNode
         * if they want to
         */
        cloneNode(deep) {
            const thisClone = this.deepClone();
            if (deep) {
                Array.from(this.childNodes).forEach((child) => {
                    thisClone.appendChild(child.cloneNode(true));
                });
            }
            return thisClone;
        }
        /**
         * @privateRemarks
         * Basic implementation of a copy constructor which creates a new element of the same class
         * and copies all attributes over.
         * None-trivial elements will likely want to override this function, call it using super.deepClone(),
         * and then perform extra setup such as copying properties, setting up event listeners
         */
        deepClone() {
            const copy = document.createElement(this.tagName.toLowerCase());
            this.getAttributeNames().forEach((at) => copy.setAttribute(at, this.getAttribute(at)));
            return copy;
        }
        /**
         * @beta
         * @returns - boolean controlling whether to run all disconnectedCallback lifecycle functionality
         */
        get shouldRunDisconnect() {
            if (__classPrivateFieldGet(this, __shouldForceLifecycle, "f")) {
                return true;
            }
            if (__classPrivateFieldGet(this, __container, "f")._key === 'dom') {
                return true;
            }
            if (__classPrivateFieldGet(this, __container, "f")._key === 'foundation-layout-cache') {
                return false;
            }
            // _key === 'foundation-layout'
            return !(__classPrivateFieldGet(this, __container, "f").dragging ||
                !__classPrivateFieldGet(this, __container, "f").hasFirstLoaded ||
                __classPrivateFieldGet(this, _instances, "m", __blockLifecycleDueToTokenChange).call(this, 'disconnect'));
        }
        /**
         * @beta
         * @returns - boolean controlling whether to run all connectedCallback lifecycle functionality
         * @privateRemarks
         * For now its just the same logic as shouldRunDisconnect
         */
        get shouldRunConnect() {
            if (__classPrivateFieldGet(this, __shouldForceLifecycle, "f")) {
                return true;
            }
            if (__classPrivateFieldGet(this, __container, "f")._key === 'dom') {
                return true;
            }
            if (__classPrivateFieldGet(this, __container, "f")._key === 'foundation-layout-cache') {
                return false;
            }
            // _key === 'foundation-layout'
            let connectionType = 'reconnect';
            if (__classPrivateFieldGet(this, __hasFirstLoaded, "f") === false) {
                __classPrivateFieldSet(this, __hasFirstLoaded, true, "f");
                connectionType = 'connect';
            }
            return !(__classPrivateFieldGet(this, __container, "f").dragging ||
                !__classPrivateFieldGet(this, __container, "f").hasFirstLoaded ||
                __classPrivateFieldGet(this, _instances, "m", __blockLifecycleDueToTokenChange).call(this, connectionType));
        }
        connectedCallback() {
            super.connectedCallback();
            if (__classPrivateFieldGet(this, __container, "f")._key !== 'foundation-layout') {
                __classPrivateFieldSet(this, __container, __classPrivateFieldGet(this, _instances, "m", __tryFindContainingLayout).call(this, this), "f");
            }
        }
    },
    __container = new WeakMap(),
    __latestTokenCode = new WeakMap(),
    __hasFirstLoaded = new WeakMap(),
    __cleanupTimeout = new WeakMap(),
    __shouldForceLifecycle = new WeakMap(),
    _instances = new WeakSet(),
    __blockLifecycleDueToTokenChange = function __blockLifecycleDueToTokenChange(lifecycleType) {
        var _a, _b;
        if (__classPrivateFieldGet(this, __container, "f")._key !== 'foundation-layout') {
            throw new Error('LifecycleMixin: should not be checking a token change if container not in the layout');
        }
        const tokensDifferent = __classPrivateFieldGet(this, __latestTokenCode, "f") !== __classPrivateFieldGet(this, __container, "f").lifecycleUpdateToken;
        let result = false;
        if (lifecycleType === 'connect') {
            // We always want to allow a first connection in the layout
            __classPrivateFieldSet(this, __latestTokenCode, (_a = __classPrivateFieldGet(this, __container, "f").lifecycleUpdateToken) !== null && _a !== void 0 ? _a : '', "f");
        }
        else if (lifecycleType === 'disconnect') {
            result = tokensDifferent;
            __classPrivateFieldSet(this, __cleanupTimeout, setTimeout(() => {
                __classPrivateFieldSet(this, __shouldForceLifecycle, true, "f");
                this.disconnectedCallback();
            }, CLEANUP_TIMEOUT_MS), "f");
        }
        else if (lifecycleType === 'reconnect') {
            result = tokensDifferent;
            __classPrivateFieldSet(this, __latestTokenCode, (_b = __classPrivateFieldGet(this, __container, "f").lifecycleUpdateToken) !== null && _b !== void 0 ? _b : '', "f");
            clearTimeout(__classPrivateFieldGet(this, __cleanupTimeout, "f"));
        }
        return result;
    },
    __tryFindContainingLayout = function __tryFindContainingLayout(e) {
        /**
         * This is a special case where the element is part of the layout cache
         * signified by a symbol put on the document cache root
         */
        if (e.getRootNode()[layoutCacheDocument] === true) {
            return { _key: 'foundation-layout-cache' };
        }
        /**
         * If this happens we have found the root of the document
         * without finding a containing FoundationLayout
         * hence, this item is not in a custom layout
         */
        if (e.getRootNode() instanceof Document) {
            return { _key: 'dom' };
        }
        const shadowHost = e.getRootNode().host;
        if (shadowHost.class === 'FoundationLayoutMain') {
            const layoutHost = shadowHost;
            layoutHost._key = 'foundation-layout';
            return layoutHost;
        }
        return __classPrivateFieldGet(this, _instances, "m", __tryFindContainingLayout).call(this, shadowHost);
    },
    _a; };
/**
 * Stored on the layout's internal cache to signify that the document is not part of the DOM
 * @public
 */
export const layoutCacheDocument = Symbol('layout-cache-document');
