/**
 * Creates a new event observer instance.
 * @public
 */
export const createObserver = () => {
    let listeners = [];
    return {
        subscribe(listener) {
            listeners.push(listener);
            return () => (listeners = listeners.filter((l) => l !== listener));
        },
        publish(event) {
            listeners.forEach((l) => l(event));
        },
    };
};
/**
 * Setup an `IntersectionObserver` which will activate a callback function when an element becomes visible on screen
 * @param element - HTMLElement to observe
 * @param callback - any function called when the visibility changes
 * @public
 */
export const respondToVisibility = (element, callback) => {
    const options = {
        root: document.documentElement,
    };
    const observer = new IntersectionObserver((entries) => {
        entries.forEach((entry) => {
            callback(entry.intersectionRatio > 0);
        });
    }, options);
    observer.observe(element);
};
