import { getType, ISO8601, NaNSymbol } from './types';
/**
 * JSON reviver function.
 * @param key - The object key.
 * @param value - The key value.
 * @returns The resulting value.
 * @public
 */
export function JSONReviver(key, value) {
    if (typeof value === 'string') {
        const isDate = ISO8601.exec(value);
        if (isDate) {
            return new Date(value);
        }
        else if (value === NaNSymbol) {
            return Number.NaN;
        }
    }
    else {
        const typeId = value && value.type;
        if (typeId) {
            const ctor = getType(typeId);
            if (ctor) {
                if ('fromJSON' in ctor) {
                    return ctor.fromJSON(value);
                }
                return new ctor(value);
            }
        }
    }
    return value;
}
