/**
 * @internal
 */
export const ISO8601 = /^\d{4}-(0[1-9]|1[0-2])-([12]\d|0[1-9]|3[01])([T\s](([01]\d|2[0-3])\:[0-5]\d|24\:00)(\:[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3])\:?([0-5]\d)?)?)?$/;
/**
 * @internal
 */
export const NaNSymbol = '$NaN';
/**
 * @internal
 */
const keyToConstructor = new Map();
/**
 * @internal
 */
export const getType = (typeId) => keyToConstructor.get(typeId);
/**
 * @internal
 */
export const getTypeId = (object) => {
    if (object) {
        if (object.type) {
            return object.type;
        }
        const proto = Object.getPrototypeOf(object);
        if (!proto) {
            return void 0;
        }
        const ctor = proto.constructor;
        if (!ctor) {
            return void 0;
        }
        for (const [key, value] of keyToConstructor) {
            if (ctor === value) {
                return key;
            }
        }
        return void 0;
    }
};
