import { logger } from '../utils/logger';
/**
 * Inserts a CSS rule into the document by creating a new style element or using an existing one with the specified ID.
 * Returns a function that can be called to remove the rule from the document.
 * @public
 * @param cssRule - The CSS rule to insert.
 * @param styleElementId - The ID of the style element to use or create.
 * @returns A function that removes the rule from the document.
 */
export const insertDocumentCSSRule = (cssRule, styleElementId) => {
    var _a;
    let styleElement = document.getElementById(styleElementId);
    if (styleElement) {
        logger.debug(`
      An element with the id of '${styleElementId}' already exists and likely has the css rules applied.
    `);
        return;
    }
    const headElement = (_a = document.head) !== null && _a !== void 0 ? _a : document.getElementsByTagName('head')[0];
    styleElement = document.createElement('style');
    styleElement.id = styleElementId;
    headElement.appendChild(styleElement);
    const styleIndex = styleElement.sheet.insertRule(cssRule);
    return () => {
        if (!styleElement) {
            return;
        }
        styleElement.sheet.deleteRule(styleIndex);
        headElement.removeChild(styleElement);
    };
};
/**
 * Inserts a CSS link into the document if it doesn't already exist.
 * @public
 * @param href - The URL of the CSS file to insert.
 */
export const insertDocumentLink = (href) => {
    const links = document.head.querySelectorAll('link');
    // Already been injected
    for (const index in links)
        if (links[index].href === href)
            return;
    const link = document.createElement('link');
    link.rel = 'stylesheet';
    link.href = href;
    document.head.appendChild(link);
};
