import { __decorate } from "tslib";
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
/**
 * A custom element that encapsulates a set of styles that can be applied to slotted elements.
 * @public
 */
let SlottedStyles = class SlottedStyles extends FASTElement {
    /**
     * Called when the `styles` property changes.
     * Removes the previous styles from the parent element's FAST controller and adds the new styles.
     * @param prev - The previous value of the `styles` property.
     * @param next - The new value of the `styles` property.
     */
    stylesChanged(prev, next) {
        if (prev) {
            this.parentElement.$fastController.removeStyles(prev);
        }
        this.parentElement.$fastController.addStyles(next);
    }
};
__decorate([
    observable
], SlottedStyles.prototype, "styles", void 0);
SlottedStyles = __decorate([
    customElement({
        name: 'slotted-styles',
    })
    /**
     * A custom element that encapsulates a set of styles that can be applied to slotted elements.
     */
], SlottedStyles);
export { SlottedStyles };
