import { insertDocumentCSSRule } from './dom';
/**
 * Loads font faces by inserting a style element with the specified font face rules into the document.
 * @param fontFaceRules - The CSS rules for the font faces.
 * @param styleElementId - The ID of the style element to insert into the document.
 * @public
 */
export const loadFontFaces = (fontFaceRules, styleElementId) => {
    insertDocumentCSSRule(fontFaceRules, styleElementId);
};
/**
 * An enum of possible font styles.
 * @public
 */
export var FontStyle;
(function (FontStyle) {
    FontStyle["Italic"] = "italic";
    FontStyle["Normal"] = "normal";
})(FontStyle || (FontStyle = {}));
/**
 * An enum of possible font weights.
 * @public
 */
export var FontWeight;
(function (FontWeight) {
    FontWeight[FontWeight["Thin"] = 100] = "Thin";
    FontWeight[FontWeight["Light"] = 300] = "Light";
    FontWeight[FontWeight["Regular"] = 400] = "Regular";
    FontWeight[FontWeight["Medium"] = 500] = "Medium";
    FontWeight[FontWeight["Bold"] = 700] = "Bold";
    FontWeight[FontWeight["Black"] = 900] = "Black";
})(FontWeight || (FontWeight = {}));
/**
 * Generates a CSS mixin for the specified font family, style, and weight.
 * @param family - The font family.
 * @param style - Optional. The font style. Defaults to FontStyle.Normal.
 * @param weight - Optional. The font weight. Defaults to FontWeight.Regular.
 * @returns The generated CSS mixin.
 * @public
 */
export const getFontMixin = (family, style = FontStyle.Normal, weight = FontWeight.Regular) => `
  font-family: ${family};
  font-style: ${style};
  font-weight: ${weight};
`;
/**
 * An object containing type ramp values.
 * @public
 */
export const TypeRampValues = {
    minusOne: -1,
    minusTwo: -2,
    plusOne: 1,
    plusTwo: 2,
    plusThree: 3,
    plusFour: 4,
    plusFive: 5,
    plusSix: 6,
};
