import { __awaiter } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { v4 as uuidv4 } from 'uuid';
import { logger } from '../utils';
/**
 * A service that implements the UUID interface and provides default UUID generation using the uuidv4 library.
 */
class UUIDService {
    /**
     * Constructs a new instance of the UUIDService.
     */
    constructor() { }
    /**
     * Generates a new UUID.
     * @param withLogging - Optional. Whether to log the generated UUID to the console. Defaults to false.
     * @returns The generated UUID.
     */
    createId(withLogging = false) {
        /**
         * Use this.config to customize uuidv4.
         */
        const id = uuidv4();
        withLogging && logger.debug(`UUID.createID ${id}`);
        return id;
    }
    /**
     * Generates a new UUID for a remote object.
     * @param withLogging - Optional. Whether to log the generated UUID to the console. Defaults to false.
     * @returns A promise that resolves to the generated UUID.
     */
    createRemoteId(withLogging = false) {
        return __awaiter(this, void 0, void 0, function* () {
            /**
             * TODO: Revisit async nature of id generation with potential server involvement
             * Use this.config to customize uuidv4.
             */
            const id = uuidv4();
            withLogging && logger.debug(`UUID.createRemoteID ${id}`);
            return id;
        });
    }
}
/**
 * A dependency injection token for the UUID interface.
 * @public
 */
export const UUID = DI.createInterface((x) => x.singleton(UUIDService));
