/**
 * Returns a boolean value indicating whether the current window is inside an iframe.
 * @returns true if the window is inside an iframe, false otherwise.
 * @public
 */
export const inIFrame = () => {
    try {
        return window.self !== window.top;
    }
    catch (e) {
        return true;
    }
};
/**
 * Returns a boolean value indicating whether the user is running the Symphony desktop app.
 * @returns true if the user is running the Symphony desktop app, false otherwise.
 * @public
 */
export const inSymphonyDesktop = () => {
    const userAgent = navigator === null || navigator === void 0 ? void 0 : navigator.userAgent;
    return (userAgent === null || userAgent === void 0 ? void 0 : userAgent.includes('Symphony')) && (userAgent === null || userAgent === void 0 ? void 0 : userAgent.includes('Electron'));
};
/**
 * The default width (in pixels) for pop-up windows.
 * @public
 */
export const POPUP_DEFAULT_WIDTH = 483;
/**
 * The default height (in pixels) for pop-up windows.
 * @public
 */
export const POPUP_DEFAULT_HEIGHT = 600;
/**
 * Opens a new browser window with the specified URL, target, width, and height.
 * @param urlNavigate - The URL to navigate to.
 * @param target - The name of the new window.
 * @param popUpWidth - The width of the new window (optional).
 * @param popUpHeight - The height of the new window (optional).
 * @returns A reference to the new window.
 * @public
 */
export const openPopup = (urlNavigate, target, popUpWidth = POPUP_DEFAULT_WIDTH, popUpHeight = POPUP_DEFAULT_HEIGHT) => {
    const left = window.innerWidth / 2 - popUpWidth / 2 + window.screenX;
    const top = window.innerHeight / 2 - popUpHeight / 2 + window.screenY;
    const popupWindow = window.open(urlNavigate, target, 'width=' +
        popUpWidth +
        ', height=' +
        popUpHeight +
        ', top=' +
        top +
        ', left=' +
        left +
        ', scrollbars=yes');
    if (popupWindow.focus) {
        popupWindow.focus();
    }
    return popupWindow;
};
